@@ -1,15 +1,21 @@
-/* Algorithm P of Knuth, fasc2b.pdf, 7.2.1.2, p4.
+/* Algorithm L of Knuth, fasc2b.pdf, 7.2.1.2, p1.
+
+   Given a sequence of n elements a1,a2,...,an initially sorted so
+   that a1 <=a2 <- ... <= an, generate all permutations of {a1,...,an}
+   visiting them in lexicographic order.  For example, the
+   permutations of 1223 are
+
+  1223 1232 1322 2123 2132 2213 2231 2312 2321 3122 3212 3221
 
-   Given integer n, generate all factorial(n) permutations.
 
-   Off-by-one alert: Knuth uses 1 to n; I use 0 to n-1.
 */
 
+
 int nextperm(int *a, const int n){
 
   int j,k, l=n-1, m;
 
-  for(j=n-2 ; a[j]>a[j+1] ; j--){ } /* L2 */
+  for(j=n-2 ; a[j] >= a[j+1] ; j--){ } /* L2 */
 
   if(j<0){
     return 1;  /* algorithm terminated: no successor */
@@ -37,15 +43,18 @@ int nextperm(int *a, const int n){
   return 0;
 
 }
-void c_allperms(int *a, const int *nin, const int *fn){
-	const int n = *nin;
+
+void c_allperms(const int *starta, const int *lenn, const int *ncol, int *a){
+	const int n = *lenn; /* lenn == length of starta */
+	const int nc = *ncol; /* nc =  number of columns of starta */
+	
 	int i;
 
 	for(i=0 ; i<n  ;i++){
-		a[i] = i+1;
+		a[i] = starta[i];
 	}
 
-	for(i=1 ; i < (*fn) ; i++){
+	for(i=1 ; i < nc ; i++){
 	  for(int j=0 ; j<n ; j++){
 	    a[i*n + j] = a[(i-1)*n+j];
 	  }
@@ -53,6 +62,12 @@ void c_allperms(int *a, const int *nin, const int *fn){
 	}
 }
 
+/* Algorithm P of Knuth, fasc2b.pdf, 7.2.1.2, p4: "plain changes".
+   Given integer n, generate all factorial(n) permutations.
+   Off-by-one alert: Knuth uses 1 to n; I use 0 to n-1.
+*/
+
+
 void c_plainperms(int *x, const int *nin, const int *fn){
   const int n = *nin;
   int i,j,m,q,s,i1,i2;
